@@ -585,9 +585,7 @@ def make_boost_base_options():
     return [
         IncludeDir("BOOST", []),
         LibraryDir("BOOST", []),
-        Option("BOOST_COMPILER", default="gcc43",
-            help="The compiler with which Boost C++ was compiled, e.g. gcc43"),
-        ]
+    ]
 
 
 
