@@ -1619,8 +1619,9 @@ class MotifFinder(object):
             instance_finder()
             bg_stats = analyse_num_instances(instance_finder.instances, self.bg_sequences)
             logger.info(
-                'Found %d instances in %d bases in %d BACKGROUND sequences for %.1e instances/base for a %.1f-fold enrichment in the input',
-                bg_stats.count, bg_stats.num_bases, bg_stats.num_seqs, bg_stats.per_base, input_stats.per_base/bg_stats.per_base
+                'Found %d instances in %d bases in %d BACKGROUND sequences for %.1e instances/base%s',
+                bg_stats.count, bg_stats.num_bases, bg_stats.num_seqs, bg_stats.per_base, 
+                bg_stats.per_base and (' for a %.1f-fold enrichment in the input' % (input_stats.per_base/bg_stats.per_base)) or ''
             )
         
         
